@@ -10,6 +10,39 @@ from . import shared_tools
 
 class water_tools(abc.ABC):
 
+    def route_water(self):
+        """Water routing main method.
+
+        This is the main method for water routing in the model. It is
+        called once per `update()` call.
+
+        Internally, this method calls:
+            * :obj:`init_water_iteration`
+            * :obj:`run_water_iteration`
+            * :obj:`compute_free_surface`
+            * :obj:`finalize_water_iteration`
+        """
+        _msg = 'Beginning water iteration'
+        self.log_info(_msg, verbosity=2)
+
+        for iteration in range(self._itermax):
+
+            # initialize the relevant fields and parcel trackers
+            self.hook_init_water_iteration()
+            self.init_water_iteration()
+
+            # run the actual iteration of the parcels
+            self.hook_run_water_iteration()
+            self.run_water_iteration()
+
+            # accumulate the routed water parcels into free surface
+            self.hook_compute_free_surface()
+            self.compute_free_surface()
+
+            # clean up the water surface and apply boundary conditions
+            self.hook_finalize_water_iteration(iteration)
+            self.finalize_water_iteration(iteration)
+
     def init_water_iteration(self):
         """Init the water iteration routine.
         """
@@ -29,6 +62,21 @@ class water_tools(abc.ABC):
         self.pad_depth = np.pad(self.depth, 1, 'edge')
         self.pad_cell_type = np.pad(self.cell_type, 1, 'edge')
 
+    def get_inlet_weights_water(self, **kwargs):
+        """Get weight for inlet cells for water parcels.
+
+        This method determines the *weights* describing which inlet cells
+        water parcels are fed into the domain (where the cells are
+        `self.inlet`).
+        Internally, :obj:`pyDeltaRCM.shared_tools._get_inlet_weights` is
+        called, returning a balanced weighting across all inlet cells.
+
+        .. note::
+
+            Reimplement this method in custom subclasses as needed.
+        """
+        return shared_tools.get_inlet_weights(self.inlet)
+
     def run_water_iteration(self):
         """Run a single iteration of travel paths for all water parcels.
 
@@ -48,7 +96,7 @@ class water_tools(abc.ABC):
         self.log_info(_msg, verbosity=2)
 
         # configure the starting indices for each parcel
-        inlet_weights = np.ones_like(self.inlet)
+        inlet_weights = self.get_inlet_weights_water()
         start_indices = shared_tools.get_start_indices(self.inlet,
                                                        inlet_weights,
                                                        self._Np_water)
@@ -110,7 +158,7 @@ class water_tools(abc.ABC):
             new_inds, looped = _check_for_loops(
                 self.free_surf_walk_inds, new_inds, _step, self.L0,
                 self.CTR, self.stage - self.H_SL)
-            looped = looped.astype(np.bool)
+            looped = looped.astype(bool)
 
             # set the current_inds to be the new_inds values
             #   (i.e., take the step)
@@ -176,9 +224,18 @@ class water_tools(abc.ABC):
         The output from :obj:`_accumulate_free_surface_walks` is then used to
         calculate a new stage surface (``H_new``) based only on the water
         parcel paths and expected water surface elevations, approximately as
-        ``H_new = sfc_sum / sfc_visit``. Finally, the updated water surface is
+        ``Hnew = sfc_sum / sfc_visit`` ("computed Hnew" in figure below)
+
+        Following this step, a correction is applied forcing the new free
+        surface to be below sea level and above or equal to the land surface
+        elevation over the model domain ("stage" in figure below). This
+        surface `Hnew` is used in the following operation
+        :obj:`finalize_free_surface`.
+
+        Finally, the updated water surface is
         combined with the previous timestep's water surface and an
-        underrelaxation coefficient :obj:`_omega_sfc`.
+        underrelaxation coefficient
+        :obj:`~pyDeltaRCM.model.DeltaModel.omega_sfc`.
 
         .. plot:: water_tools/compute_free_surface_outputs.py
 
@@ -201,8 +258,49 @@ class water_tools(abc.ABC):
             self.uw, self.ux, self.uy, self.depth,
             self._dx, self._u0, self.h0, self._H_SL, self._S0)
 
+        # begin from the previous stage
+        Hnew = self.eta + self.depth
+
+        # find average water surface elevation for a cell from accumulation
+        Hnew[self.sfc_visit > 0] = (self.sfc_sum[self.sfc_visit > 0] /
+                                    self.sfc_visit[self.sfc_visit > 0])
+
+        # water surface height not under sea level
+        Hnew[Hnew < self._H_SL] = self._H_SL
+
+        # water surface height not below bed elevation
+        Hnew[Hnew < self.eta] = self.eta[Hnew < self.eta]
+
+        # set to model field
+        self.Hnew = Hnew
+
+        # finalize the free surface (combine and smooth)
         self.finalize_free_surface()
 
+    def finalize_free_surface(self):
+        """Finalize the water free surface.
+
+        This method occurs after the initial computation of the free surface,
+        and creates the new free surface by smoothing the newly computed free
+        surface with a jitted function (:obj:`_smooth_free_surface`), and then
+        combining the old surface and new smoothed surface with
+        underrelaxation. Finally, a :obj:`flooding_correction` is applied.
+        """
+        _msg = 'Smoothing and finalizing free surface'
+        self.log_info(_msg, verbosity=2)
+
+        # smooth newly calculated free surface
+        Hsmth = _smooth_free_surface(
+            self.Hnew, self.cell_type, self._Nsmooth, self._Csmooth)
+
+        # combine new smoothed and previous free surf with underrelaxation
+        if self._time_iter > 0:
+            self.stage = (((1 - self._omega_sfc) * self.stage) +
+                          (self._omega_sfc * Hsmth))
+
+        # apply a flooding correction
+        self.flooding_correction()
+
     def finalize_water_iteration(self, iteration):
         """Finish updating flow fields.
 
@@ -237,7 +335,7 @@ class water_tools(abc.ABC):
             self.log_info(_msg, verbosity=2)
 
             indices_blank = np.zeros(
-                (np.int(self._Np_water), np.int(self.stepmax / 4)), dtype=np.int)
+                (int(self._Np_water), int(self.stepmax / 4)), dtype=int)
 
             self.free_surf_walk_inds = np.hstack((self.free_surf_walk_inds, indices_blank))
 
@@ -326,43 +424,6 @@ class water_tools(abc.ABC):
         boundary = (self.cell_type.flat[inds] == -1)
         return boundary
 
-    def finalize_free_surface(self):
-        """Finalize the water free surface.
-
-        This method occurs after the initial computation of the free surface,
-        by accumulating the directed walks of all water parcels. In this
-        method, thresholding is applied to correct for sea level, and a the
-        free surface is smoothed by a jitted function
-        (:obj:`_smooth_free_surface`).
-        """
-        _msg = 'Smoothing and finalizing free surface'
-        self.log_info(_msg, verbosity=2)
-
-        # begin from the previous stage
-        Hnew = self.eta + self.depth
-
-        # find average water surface elevation for a cell from accumulation
-        Hnew[self.sfc_visit > 0] = (self.sfc_sum[self.sfc_visit > 0] /
-                                    self.sfc_visit[self.sfc_visit > 0])
-
-        # water surface height not under sea level
-        Hnew[Hnew < self._H_SL] = self._H_SL
-
-        # water surface height not below bed elevation
-        Hnew[Hnew < self.eta] = self.eta[Hnew < self.eta]
-
-        # smooth newly calculated free surface
-        Hsmth = _smooth_free_surface(
-            Hnew, self.cell_type, self._Nsmooth, self._Csmooth)
-
-        # combine new smoothed and previous free surf with underrelaxation
-        if self._time_iter > 0:
-            self.stage = (((1 - self._omega_sfc) * self.stage) +
-                          (self._omega_sfc * Hsmth))
-
-        # apply a flooding correction
-        self.flooding_correction()
-
     def update_flow_field(self, iteration):
         """Update water discharge.
 
@@ -509,7 +570,10 @@ class water_tools(abc.ABC):
 @njit
 def _get_weight_at_cell_water(ind, weight_sfc, weight_int, depth_nbrs, ct_nbrs,
                               dry_depth, gamma, theta):
+    """Compute water weights for a given cell.
 
+    This is a jitted function called by :func:`_get_water_weight_array`.
+    """
     # create a fixed set of bools
     dry = (depth_nbrs < dry_depth)
     wall = (ct_nbrs == -2)
@@ -762,7 +826,7 @@ def _check_for_loops(free_surf_walk_inds, new_inds, _step,
         the inlet domain edge.
 
     stage_above_SL
-        Water surface elevation minuns the domain sea level.
+        Water surface elevation minus the domain sea level.
 
     Returns
     -------
